@@ -157,7 +157,8 @@ def _add_solvent_box(molecule, new_molecule, molmin, molmax, solshape, distance,
 
 def add_solvent_box(molecule, solvent, distance, tolerance=3):
     """
-    This **function** add a box full of solvents to a molecule
+    This **function** adds a box full of solvents to a molecule.
+    This will be performed in place for a Molecule and out of place for a ResidueType.
 
     :param molecule: the molecule to add the box, either a ``Molecule`` or a ``ResidueType``
     :param solvent: the solvent molecule, either a ``Molecule`` or a ``ResidueType``
@@ -165,7 +166,7 @@ def add_solvent_box(molecule, solvent, distance, tolerance=3):
  This can be an ``int`` or a ``float``, and it can be also a list of them with the length 3 or 6, \
  which represents the 3 or 6 directions respectively.
     :param tolerance: the distance between two molecules. 3 for default.
-    :return: None
+    :return: the Molecule instance
     """
     if isinstance(distance, (float, int)):
         distance = [distance] * 6
@@ -202,7 +203,7 @@ def add_solvent_box(molecule, solvent, distance, tolerance=3):
     solshape = solmax - solmin + tolerance
 
     _add_solvent_box(molecule, new_molecule, molmin, molmax, solshape, distance, tolerance, solcrd)
-
+    return molecule
 
 def h_mass_repartition(molecules, repartition_mass=1.1, repartition_rate=3, exclude_residue_name="WAT"):
     """
@@ -371,7 +372,8 @@ def get_peptide_from_sequence(sequence, charged_terminal=True):
     return toret
 
 
-def optimize(mol, step=2000, only_bad_coordinate=True, dt=1e-8, force_limit=50, epoch_limit=10, pbc=True):
+def optimize(mol, step=2000, only_bad_coordinate=True, dt=1e-8, force_limit=50,
+             epoch_limit=10, pbc=True, extra_commands=None):
     """
     This **function** is used to optimize the structure of the Molecule instance
 
@@ -383,7 +385,8 @@ def optimize(mol, step=2000, only_bad_coordinate=True, dt=1e-8, force_limit=50,
 between forces in two steps is not more than this value.
     :param epoch_limit: the minimization will stop if the epoch is not less than this value.
     :param pbc: whether to use the periodic box condition
-    :return: None
+    :param extra_commands: a dict, with the extra commands to pass to the MD engine
+    :return: 0 for reaching the force limitation, 1 for reaching the epoch limitation
     """
     from tempfile import TemporaryDirectory
     Xprint("Optimizing", verbose=0)
@@ -413,6 +416,11 @@ step_limit = {step}
 write_information_interval = {step}
 molecule_map_output  = 1
 """)
+        towrite = ""
+        if extra_commands:
+            for command, value in extra_commands.items():
+                towrite += f"{command} = {value}\n"
+        mdin.write(towrite)
         mdin.close()
         if pbc:
             all_to_use = f"SPONGE -mdin {temp_mdin_name} "
@@ -449,6 +457,9 @@ molecule_map_output  = 1
                                                                  epoch_limit), verbose=0)
         load_coordinate(temp_out+'_coordinate.txt', mol)
         Xprint("Optimization Finished", verbose=0)
+        if np.all(np.abs(frc - last_frc) < force_limit):
+            return 0
+        return 1
 
 
 class Region(ABC):
